@@ -33,3 +33,11 @@ class TestExceptions(unittest.TestCase):
     def test_invalid_option_is_validation_error(self):
         assert isinstance(exceptions.InvalidOption('msg'),
                           exceptions.ValidationError)
+
+    def test_betamaxerror_repr(self):
+        """Ensure errors don't raise exceptions in their __repr__.
+
+        This should protect against regression. If this test starts failing,
+        heavily modify it to not be flakey.
+        """
+        assert "BetamaxError" in repr(exceptions.BetamaxError('test'))
